@@ -3,8 +3,8 @@
 
 use strict;
 
-if($#ARGV<2){
-   die "Usage: $0 <fasta file 1> <fasta file 2> <library insert size> --- ** Both files must have the same number of records & arranged in the same order\n";
+if($#ARGV<1){
+   die "Usage: $0 <fasta file 1> <fasta file 2> --- ** Both files must have the same number of records & arranged in the same order\n";
 }
 
 my $file1=$ARGV[0];
@@ -41,7 +41,7 @@ while(<IN1>){
         }
 
         if($rd1 ne "" && $rd2 ne ""){
-           print PAIR ">$template:$ARGV[2]\n$rd1:$rd2\n";
+           print PAIR ">$template\n$rd1:$rd2\n";
         }else{
            if($rd1 ne ""){
               print UNP ">$template";
