@@ -6,9 +6,8 @@
 #   rwarren at bcgsc.ca
 
 #NAME
-#   SSAKE Rene Warren, August 2008
-#   v3.2.1 is ~30% faster and requires 33% less memory compared to 15-node SSAKE3.2beta
-#   v3.2+ Adjust contig ends to find new extension possibilities.  Important bug fix - addressed issues in failure to explore all read space (README for details)
+#   SSAKE v3.2  Rene Warren, March 2008
+#   Adjust contig ends to find new extension possibilities.  Important bug fix - addressed issues in failure to explore all read space (README for details)
 #   v3.1+ Allows users to specify a seed sequence file.  This feature can be used to allow extension of existing DNA sequences using short reads
 #   v3.0+ Supports mate pairs 
 #   v2.0+ Handles errors in reads
@@ -46,32 +45,30 @@ require "getopts.pl";
 use vars qw($opt_f $opt_m $opt_o $opt_v $opt_r $opt_p $opt_d $opt_k $opt_a $opt_z $opt_e $opt_g $opt_s $opt_t $opt_b);
 &Getopts('f:m:l:o:v:r:p:d:k:a:z:e:g:s:t:b:');
 my ($base_overlap,$min_overlap,$verbose,$MIN_READ_LENGTH,$SEQ_SLIDE,$min_base_ratio,$paired,$insert_size,$min_links,$max_link_ratio,$contig_size_cutoff,$insert_stdev,$unpaired_file,$seed_file,$max_trim,$base_name)=(3,16,0,16,1,0.7,0,200,2,0.70,50,0.75,"no-g","no-s",0,"");
-my $version = "[version 3.2.1]";
 my $per;
 my $MAX = 0; 
 my $MAX_TOP = 100; # this is the very maximum anchoring edge sequence that will be searched
-my $TRACK_COUNT = 1;
 
 #-------------------------------------------------
 
 if(! $opt_f){
-   print "Usage: $0 $version\n";
+   print "Usage: $0\n";
    print "-f  Fasta file containing all the [paired (-p 1) / unpaired (-p 0)] reads (required)\n";
    print "\t! paired reads must now be separated by \":\"\n";
    print "-s  Fasta file containing sequences to use as seeds exclusively (specify only if different from read set, optional)\n";
-   print "-m  Minimum number of overlapping bases with the seed/contig during overhang consensus build up (default -m $min_overlap)\n";
-   print "-o  Minimum number of reads needed to call a base during an extension (default -o $base_overlap)\n";
-   print "-r  Minimum base ratio used to accept a overhang consensus base (default -r $min_base_ratio)\n";
-   print "-t  Trim up to -t base(s) on the contig end when all possibilities have been exhausted for an extension (default -t $max_trim)\n";
+   print "-m  Minimum number of overlapping bases with the seed/contig during overhang consensus build up (default -m 16)\n";
+   print "-o  Minimum number of reads needed to call a base during an extension (default -o 3)\n";
+   print "-r  Minimum base ratio used to accept a overhang consensus base (default -r 0.7)\n";
+   print "-t  Trim up to -t base(s) on the contig end when all possibilities have been exhausted for an extension (default -t 0)>\n";
    print "-p  Paired-end reads used? (-p 1=yes, -p 0=no, default -p 0)\n";
    print "-v  Runs in verbose mode (-v 1=yes, -v 0=no, default -v 0, optional)\n";
    print "-b  Base name for your output files (optional)\n";
    print "============ Options below only considered with -p 1 ============\n";
-   print "-d  Mean distance expected/observed between paired-end reads (default -d $insert_size, optional)\n";
-   print "-e  Error (%) allowed on mean distance   e.g. -e 0.75  == distance +/- 75% (default -e $insert_stdev, optional)\n";
-   print "-k  Minimum number of links (read pairs) to compute scaffold (default -k $min_links, optional)\n";
-   print "-a  Maximum link ratio between two best contig pairs *higher values lead to least accurate scaffolding* (default -a $max_link_ratio, optional)\n";
-   print "-z  Minimum contig size to track paired-end reads (default -z $contig_size_cutoff, optional)\n";
+   print "-d  Mean distance expected/observed between paired-end reads (default -d 200, optional)\n";
+   print "-e  Error (%) allowed on mean distance   e.g. -e 0.75  == distance +/- 75% (default -e 0.75, optional)\n";
+   print "-k  Minimum number of links (read pairs) to compute scaffold (default -k 2, optional)\n";
+   print "-a  Maximum link ratio between two best contig pairs *higher values lead to least accurate scaffolding* (default -a 0.70, optional)\n";
+   print "-z  Minimum contig size to track paired-end reads (default -z 50, optional)\n";
    die "-g  Fasta file containing unpaired sequence reads (optional)\n";
 }
 
@@ -136,8 +133,8 @@ my $distribution = $base_name . ".pairing_distribution.csv" if ($paired);
 
 open (LOG, ">$log") || die "Can't write to $log -- fatal\n";
 
-if($min_overlap < 15 || $min_overlap > 50){
-   my $outofbound_message = "-m must be a number between 15-50 ...Exiting.\n";
+if($min_overlap < 11 || $min_overlap > 50){
+   my $outofbound_message = "-m must be a number between 11-50 ...Exiting.\n";
    print $outofbound_message;
    print LOG $outofbound_message;
    close LOG;
@@ -162,7 +159,7 @@ if($min_base_ratio <= 0.5 || $min_base_ratio > 1){
 
 #-------------------------------------------------
 
-my $init_message = "\nRunning: $0 $version\n-f $file\n-m $min_overlap\n-o $base_overlap\n-r $min_base_ratio\n-t $max_trim\n";
+my $init_message = "\nRunning: $0\n-f $file\n-m $min_overlap\n-o $base_overlap\n-r $min_base_ratio\n-t $max_trim\n";
 if($paired){$init_message .= "-p $paired\n-d $insert_size\n-e $insert_stdev\n-k $min_links\n-a $max_link_ratio\n-z $contig_size_cutoff\nUnpaired reads (optional) -g $unpaired_file\n\nScaffolds file: $scaffold\nPairing issues file: $issues\nPairing distance distribution file: $distribution\n";}
 $init_message .= "Contigs file: $contig\nSinglets file: $singlet\nExcluded short reads file: $short\nLog file: $log\n";
 
@@ -178,11 +175,9 @@ my $reading_reads_message = "\nReading sequences initiated $date\n";
 print $reading_reads_message;
 print LOG $reading_reads_message;
 
-my $encoded = &encodeBases();
-
 my($set,$bin,$seed);
-($set,$bin) = &readFasta($set,$bin,$file,$short,$paired,$encoded);
-($set,$bin) = &readFasta($set,$bin,$unpaired_file,$short,0,$encoded) if (-e $opt_g);
+($set,$bin) = &readFasta($set,$bin,$file,$short,$paired);
+($set,$bin) = &readFasta($set,$bin,$unpaired_file,$short,0) if (-e $opt_g);
 
 #-------------------------------------------------
 ### Allow user to specify a fasta file containing sequences to use as seeds, exclusively
@@ -194,7 +189,6 @@ if(-e $opt_s){
    $seed = &loadSeed($opt_s); 
 }else{
    $seed = $set;
-   $TRACK_COUNT = 0;
 }
 my $seed_number_message = "Number of unique seed sequences: " . keys( %$seed ) . "\n";
 printf $seed_number_message;
@@ -235,7 +229,7 @@ foreach my $seq (sort {$seed->{$b}{'count'}<=>$seed->{$a}{'count'}} keys %$seed)
 
    my $track;
 
-   if(defined $seed->{$seq}){#sequence read hasn't been used, is longer than 15 nt and the user-defined overlap minimum -m
+   if(defined $seed->{$seq}){#sequence read hasn't been used, is longer than 11 nt and the user-defined overlap minimum -m
 
       my $seed_name = "";
       if(defined $seed->{$seq}{'name'}){$seed_name = "|seed:" . $seed->{$seq}{'name'};}
@@ -245,20 +239,21 @@ foreach my $seq (sort {$seed->{$b}{'count'}<=>$seed->{$a}{'count'}} keys %$seed)
       if($paired){$track->{$seq}{'start'} = 1;$track->{$seq}{'end'} = $orig_mer;$track->{$seq}{'tig'} = $tig_count;}
 
       #### Delete keys ref
+      my @o=split(//,$seq);                               
 
       my $start_sequence = $seq;
       my $reads_needed = $set->{$seq}{'count'};                      #tracks coverage
       my $total_bases = $orig_mer * $reads_needed;
 
-      ($bin,$set,$seed) = deleteData($bin,$set,$seed,$seq,$encoded);   #remove k-mer from hash table and prefix tree
+      ($bin,$set,$seed)=deleteData($bin,$set,$seed,$seq);   #remove k-mer from hash table and prefix tree
      
       print "\n\n>>> START SEED SEQUENCE :: $seq <<<\n\n" if ($verbose);
 
-      ($seq, $set, $bin, $reads_needed, $total_bases, $track) = doExtension("3", $orig_mer, $seq, $set, $bin, $reads_needed, $total_bases, $min_overlap, $base_overlap, $min_base_ratio, $verbose, $track, $paired, $tig_count, $max_trim, $encoded);
+      ($seq, $set, $bin, $reads_needed, $total_bases, $track) = doExtension("3", $orig_mer, $seq, $set, $bin, $reads_needed, $total_bases, $min_overlap, $base_overlap, $min_base_ratio, $verbose, $track, $paired, $tig_count, $max_trim);
       ####end of 3' extension, beginning of 5' extension  (via 3' RC)
 
       my $seqrc = reverseComplement($seq);
-      ($seqrc, $set, $bin, $reads_needed, $total_bases, $track) = doExtension("5", $orig_mer, $seqrc, $set, $bin, $reads_needed, $total_bases, $min_overlap, $base_overlap, $min_base_ratio, $verbose, $track, $paired, $tig_count, $max_trim, $encoded);
+      ($seqrc, $set, $bin, $reads_needed, $total_bases, $track) = doExtension("5", $orig_mer, $seqrc, $set, $bin, $reads_needed, $total_bases, $min_overlap, $base_overlap, $min_base_ratio, $verbose, $track, $paired, $tig_count, $max_trim);
       ####end of 5' extension
 
       my $leng = length($seqrc);
@@ -523,7 +518,7 @@ sub pairContigs{
 
       print "Pair#$template read1=$read_a read2=$read_b\n" if ($verbose);
 
-      if(defined $track->{$read_a}{'tig'} && defined $track->{$read_b}{'tig'}){### both pairs assembled
+      if(defined $track->{$read_a}{'tig'} && $track->{$read_b}{'tig'}){### both pairs assembled
 
          $ct_both++;
 
@@ -694,48 +689,49 @@ sub pairContigs{
 # SSAKE contig extension
 sub doExtension{
 
-   my ($direction, $orig_mer, $seq, $set, $bin, $reads_needed, $total_bases, $min_overlap, $base_overlap, $min_base_ratio, $verbose, $track, $paired, $tig_count, $max_trim, $e) = @_;
+   my ($direction, $orig_mer, $seq, $set, $bin, $reads_needed, $total_bases, $min_overlap, $base_overlap, $min_base_ratio, $verbose, $track, $paired, $tig_count, $max_trim) = @_;
 
    my $previous = $seq;
    my $extended = 1;
    my $trim_ct = 0;     #trim counter - keeps track of 3'-end trim
 
-   if($orig_mer > $MAX){$orig_mer=$MAX;}  ### Deals with special cases where the seed sequences are different from the read set (and possibly very large) - goal here is not to increase sequence coverage of seed, but rather to extend it.
-
    TRIM:
    while($trim_ct <= $max_trim){
+
       while($extended){
 
-         my ($pos,$current_reads,$current_bases,$span) = (0,0,0,"");
+         ### added 31Jan08 R.Warren
+         if($orig_mer > $MAX){$orig_mer=$MAX;}  ### Deals with special cases where the seed sequences are different from the read set (and possibly very large) - goal here is not to increase sequence coverage of seed, but rather to extend it.
 
-         ### Added 19March08
-         if(length($seq) >= $MAX){   # $seq is length of contig being extended -- if larger than largest read, make sure the largest read could align and all subsequent rds.
-            $span = $MAX - $TRACK_COUNT;
-         }else{
-            $span = length($seq) - $TRACK_COUNT;
-         }
+         my ($ct,$pos,$current_reads,$current_bases,$span) = (0,0,0,0,$orig_mer);
 
          my $overhang = {};
          my @overlapping_reads = ();
-         for (my $x=1;$x <= ($orig_mer * 2);$x++){
+         for (my $x=1;$x <= ($orig_mer *2);$x++){
             ($overhang->{$x}{'A'},$overhang->{$x}{'C'},$overhang->{$x}{'G'},$overhang->{$x}{'T'}) = (0,0,0,0);
          }
 
-         ### COLLECT SEQUENCES 
-         while ($span >= $min_overlap){  # will slide the subseq, until the user-defined min overlap size
+         EXTENSION:
+         while ($span > $min_overlap){  #will slide the subseq, until the user-defined min overlap size
+
+            ### Added 19March08
+            if(length($seq) >= $MAX){   # $seq is length of contig being extended -- if larger than largest read, make sure the largest read could align and all subsequent rds. 
+               $span = $MAX - $ct;
+            }else{
+               $span = length($seq) - $ct;
+            }
 
             $pos = length($seq) - $span;
-            print "MAX:$MAX, SPAN:$span, POS:$pos" if ($verbose);
 
-            my $subseq = substr($seq, $pos, $span);              #make a sub-sequence of length l-(1..i) for searching
-            my @s = $subseq =~ /\S{3}/g;
-            my $subset = $bin->{$e->{$s[0]}}{$e->{$s[1]}}{$e->{$s[2]}}{$e->{$s[3]}}{$e->{$s[4]}}; #Will grab everything even the reverse complement ones
+            my $subseq = substr($seq, $pos, $span);                                                            #make a sub-sequence of length l-(1..i) for searching
 
-            print "####$direction' SEARCH Position:$pos Span:$span - Subseq:$subseq Previous:$previous\n" if ($verbose);
+            my @s=split(//,$subseq);
+            my $subset = $bin->{$s[0]}{$s[1]}{$s[2]}{$s[3]}{$s[4]}{$s[5]}{$s[6]}{$s[7]}{$s[8]}{$s[9]}{$s[10]}; #Will grab everything even the reverse complement ones
 
-            ### SEARCH -- this cycles through limited k-mer space
+            print "####$direction' SEARCH Counter:$ct Position:$pos Span:$span - Subseq:$subseq Previous:$previous\n" if ($verbose);
+
+            SEARCH:   #this cycles through limited k-mer space
             foreach my $pass (sort {$subset->{$b} <=> $subset->{$a}} keys %$subset){
-
                if($pass =~ /^$subseq([ACGT]*)/){ 
                   #can we align perfectly that subseq to another rd start?
                   my $dangle = $1;
@@ -766,7 +762,7 @@ sub doExtension{
                      $current_bases = length($pass) * $current_reads;
                      $reads_needed += $current_reads;
                      $total_bases += $current_bases;
-                     ($bin,$set,$seed) = deleteData($bin,$set,$seed,$pass,$e);
+                     ($bin,$set,$seed) = deleteData($bin,$set,$seed,$pass);
                      if($paired && ! defined $track->{$pass}){
                         $track->{$pass}{'tig'} = $tig_count;
                         $track->{$pass}{'start'} = $pos + 1;
@@ -778,7 +774,7 @@ sub doExtension{
                      $current_bases = length($complement_pass) * $current_reads;
                      $reads_needed += $current_reads;
                      $total_bases += $current_bases;
-                     ($bin,$set,$seed) = deleteData($bin,$set,$seed,$complement_pass,$e);
+                     ($bin,$set,$seed) = deleteData($bin,$set,$seed,$complement_pass);
                      if($paired && ! defined $track->{$complement_pass}){ 
                         $track->{$complement_pass}{'tig'} = $tig_count;
                         $track->{$complement_pass}{'end'} = $pos + 1;
@@ -787,9 +783,9 @@ sub doExtension{
                   }
                }  
             }
-            $span--;
+            $ct += $SEQ_SLIDE;
          }#while overlap >= user-defined -m minimum
-
+ 
          my $consensus = "";
          print "Finished Collecting Overlapping Reads - BUILDING CONSENSUS...\n" if ($verbose);
          print Dumper(@overlapping_reads) if ($verbose);
@@ -838,8 +834,7 @@ sub doExtension{
             my $integral = 0;
             foreach my $ro (@overlapping_reads){
 
-               while($temp_sequence =~ /$ro/g){
-
+               while($temp_sequence =~ /$ro/g){                                   ### read found integral in the newly built sequence
                   my $complement_ro = reverseComplement($ro);
                   $integral=1;
 
@@ -850,7 +845,7 @@ sub doExtension{
                      $current_bases = length($ro) * $current_reads;
                      $reads_needed += $current_reads;
                      $total_bases += $current_bases;
-                     ($bin,$set,$seed) = deleteData($bin,$set,$seed,$ro,$e);
+                     ($bin,$set,$seed) = deleteData($bin,$set,$seed,$ro);
                      if($paired && ! defined $track->{$ro}){
                         $track->{$ro}{'tig'} = $tig_count;
                         $track->{$ro}{'start'} = (pos $temp_sequence) - length($ro) + 1;
@@ -864,7 +859,7 @@ sub doExtension{
                      $current_bases = length($complement_ro) * $current_reads;
                      $reads_needed += $current_reads;
                      $total_bases += $current_bases;
-                     ($bin,$set,$seed) = deleteData($bin,$set,$seed,$complement_ro,$e);
+                     ($bin,$set,$seed) = deleteData($bin,$set,$seed,$complement_ro);
                      if($paired && ! defined $track->{$complement_ro}){
                         $track->{$complement_ro}{'tig'} = $tig_count;
                         $track->{$complement_ro}{'end'} = (pos $temp_sequence) - length($complement_ro) + 1;
@@ -913,54 +908,19 @@ sub doExtension{
 
 #-----------------------
 sub deleteData {
-   my ($bin,$set,$seed,$sequence,$e) = @_;
+   my ($bin,$set,$seed,$sequence) = @_;
    
-   my @o = $sequence =~ /\S{3}/g;
+   my @o=split(//,$sequence);
    my $comp_seq = reverseComplement($sequence);
-   my @c = $comp_seq =~ /\S{3}/g;
+   my @c=split(//,$comp_seq);
 
    #remove k-mer from hash table and prefix tree
-   delete $bin->{$e->{$o[0]}}{$e->{$o[1]}}{$e->{$o[2]}}{$e->{$o[3]}}{$e->{$o[4]}}{$sequence};
-   delete $bin->{$e->{$c[0]}}{$e->{$c[1]}}{$e->{$c[2]}}{$e->{$c[3]}}{$e->{$c[4]}}{$comp_seq};
+   delete $bin->{$o[0]}{$o[1]}{$o[2]}{$o[3]}{$o[4]}{$o[5]}{$o[6]}{$o[7]}{$o[8]}{$o[9]}{$o[10]}{$sequence};
+   delete $bin->{$c[0]}{$c[1]}{$c[2]}{$c[3]}{$c[4]}{$c[5]}{$c[6]}{$c[7]}{$c[8]}{$c[9]}{$c[10]}{$comp_seq};
    delete $set->{$sequence};
    delete $seed->{$sequence};
 
-   return $bin, $set, $seed;
-}
-
-#-----------------------
-sub deletePrefixTree{
-   my ($bin,$h,$e) = @_;
-
-   my @o = @$h;
-
-   ### forward ::
-   my $fwd_list_5 = $bin->{$e->{$o[0]}}{$e->{$o[1]}}{$e->{$o[2]}}{$e->{$o[3]}}{$e->{$o[4]}};
-   my $values_in_bin = grep { $_ ne "" } values %$fwd_list_5;
-   if (! $values_in_bin){
-      delete $bin->{$e->{$o[0]}}{$e->{$o[1]}}{$e->{$o[2]}}{$e->{$o[3]}}{$e->{$o[4]}};
-      $fwd_list_5 = $bin->{$e->{$o[0]}}{$e->{$o[1]}}{$e->{$o[2]}}{$e->{$o[3]}};
-      $values_in_bin = grep { $_ ne "" } values %$fwd_list_5;
-      if (! $values_in_bin){
-         delete $bin->{$e->{$o[0]}}{$e->{$o[1]}}{$e->{$o[2]}}{$e->{$o[3]}};
-         $fwd_list_5 = $bin->{$e->{$o[0]}}{$e->{$o[1]}}{$e->{$o[2]}};
-         $values_in_bin = grep { $_ ne "" } values %$fwd_list_5;
-         if (! $values_in_bin){
-            delete $bin->{$e->{$o[0]}}{$e->{$o[1]}}{$e->{$o[2]}};
-            $fwd_list_5 = $bin->{$e->{$o[0]}}{$e->{$o[1]}};
-            $values_in_bin = grep { $_ ne "" } values %$fwd_list_5;
-            if (! $values_in_bin){
-               delete $bin->{$e->{$o[0]}}{$e->{$o[1]}};
-               $fwd_list_5 = $bin->{$e->{$o[0]}};
-               $values_in_bin = grep { $_ ne "" } values %$fwd_list_5;
-               if (! $values_in_bin){
-                  delete $bin->{$e->{$o[0]}};
-               }
-            }
-         }
-      }
-   }
-   return $bin;
+   return $bin,$set,$seed;
 }
 #-----------------------
 sub reverseComplement{
@@ -999,15 +959,13 @@ sub readClone{
 
 #-----------------
 sub readFasta{
-   my ($set,$bin,$file,$short,$paired,$encoded) = @_;
+   my ($set,$bin,$file,$short,$paired) = @_;
 
    my $ctrd = 0;
 
    open(IN,$file) || die "Can't open $file -- fatal\n";
    open (SHO, ">>$short") || die "Can't write to $short -- fatal\n";
 
-   print "Sequence reads inputted:\n";
-
    while(<IN>){
       chomp;
       if(/^([^\>]*)$/i){
@@ -1015,8 +973,8 @@ sub readFasta{
 
          if($paired){
             if($sdna =~/^([ACGT]*)\:([ACGT]*)$/i){
-               ($set,$bin,$ctrd) = &loadSequence($set,$bin,$ctrd,$1,$encoded);
-               ($set,$bin,$ctrd) = &loadSequence($set,$bin,$ctrd,$2,$encoded);
+               ($set,$bin,$ctrd) = &loadSequence($set,$bin,$ctrd,$1);
+               ($set,$bin,$ctrd) = &loadSequence($set,$bin,$ctrd,$2);
             }else{
                my $pairing_failure_message = "The sequence \"$sdna\" is not in the right format for paired-end reads  -- Fatal\nMake sure your input is in the form (input sequences can be of variable lengths):\n\n>test\nGCTACGACTATGACATACAGT:GTAGATTGATCGCATGCACGCT\n\nWhere : separates paired reads.  Spaces in your input file might have caused this error.\n";
                print $pairing_failure_message;
@@ -1025,14 +983,14 @@ sub readFasta{
                exit;
             }
          }else{
-            ($set,$bin,$ctrd) = &loadSequence($set,$bin,$ctrd,$1,$encoded) if ($sdna =~ /^([ACGT]*)$/i);
+            ($set,$bin,$ctrd) = &loadSequence($set,$bin,$ctrd,$1) if ($sdna =~ /^([ACGT]*)$/i);
          }
       }
    }
    close IN;
    close SHO;
 
-   my $read_number_message = "\r$ctrd total sequences (" . keys( %$set ) . " unique)\n";
+   my $read_number_message = "$ctrd total sequences (" . keys( %$set ) . " unique)\n";
    printf $read_number_message;
    print LOG $read_number_message;
 
@@ -1082,34 +1040,36 @@ sub loadSeed{
 #-----------------
 sub loadSequence{
 
-   my ($set,$bin,$ctrd,$seq,$e) = @_;
+   my ($set,$bin,$ctrd,$seq) = @_;
 
    my $orig=uc($seq);
    my $orig_mer = length($orig);
 
    if ($orig ne '' && $orig_mer >= $MIN_READ_LENGTH && $orig_mer >= $min_overlap){
+      ####show progress
+      my $s10k = $ctrd / 10000;
+      print "." if ($s10k == int($s10k) && $s10k && $ctrd);
+      $|=1; ###clear buffer
 
-      my @f = $orig =~ /\S{3}/g;
+      my $s100k = $ctrd / 100000;
+      printf "%i sequences inputted\n", ($ctrd) if ($s100k == int($s100k) && $s100k && $ctrd);
+
+      my @f=split(//,$orig);
+      $set->{$orig}{'count'}++;
 
       $_ = $orig;
       tr/ACTG/TGAC/;
       my $rc=reverse();
 
-      my @r = $rc =~ /\S{3}/g;
+      my @r=split(//,$rc);
 
       ### added 31Jan08 R.Warren
       $MAX=$orig_mer if ($orig_mer > $MAX);
 
-      $set->{$orig}{'count'}++;
-      $bin->{$e->{$f[0]}}{$e->{$f[1]}}{$e->{$f[2]}}{$e->{$f[3]}}{$e->{$f[4]}}{$orig}++;
-      $bin->{$e->{$r[0]}}{$e->{$r[1]}}{$e->{$r[2]}}{$e->{$r[3]}}{$e->{$r[4]}}{$rc}++;
-
+      $bin->{$f[0]}{$f[1]}{$f[2]}{$f[3]}{$f[4]}{$f[5]}{$f[6]}{$f[7]}{$f[8]}{$f[9]}{$f[10]}{$orig}++;
+      $bin->{$r[0]}{$r[1]}{$r[2]}{$r[3]}{$r[4]}{$r[5]}{$r[6]}{$r[7]}{$r[8]}{$r[9]}{$r[10]}{$rc}++;
       $ctrd++;
-
-      ####show progress
-      print "\r$ctrd";
-      $|++; 
-
+      
    }elsif($orig ne ''){
       if($orig_mer < $MIN_READ_LENGTH){
          print SHO "$seq\tInput sequence shorter than minimum read length allowed ($orig_mer < $MIN_READ_LENGTH nt)\n";
@@ -1122,29 +1082,4 @@ sub loadSequence{
    return $set,$bin,$ctrd;
 }
 
-#-----------------
-sub encodeBases{
-
-   my $encoded;
-
-   my @pos1= ('A','C','G','T');
-   my @pos2 = @pos1;
-   my @pos3 = @pos1;
- 
-   my $ascii_num = 33;
-
-   foreach my $p1 (@pos1){
-      foreach my $p2 (@pos2){
-         foreach my $p3 (@pos3){
-            my $codon = $p1.$p2.$p3;
-            #$num  = ord($char);
-            my $char = chr($ascii_num);
-            $encoded->{$codon}=$char;
-            $ascii_num++;
-         } 
-      }
-   }
-   return $encoded;
-}
-
 ### We hope this code is useful to you -- Please send comments & suggestions to rwarren at bcgsc.ca
